==> chainwallet-1.0.2.tar.gz: lib/src/core/serialized/BinarySerializer.dart <==

import 'dart:typed_data';

import "./BytesSink.dart";
import "./ByteList.dart";
import "./SerializedType.dart";
import "../fields/Field.dart";
import "../fields/Type.dart";

class BinarySerializer {
  BytesSink sink;

  BinarySerializer(BytesSink sink) {
    this.sink = sink;
  }

  void addBytes(List<int> n) {

    Uint8List bytes = Uint8List.fromList(n);
    sink.addBytes(bytes);
  }

//  void addLengthEncoded(byte[] n) {
//    add(encodeVL(n.length));
//    add(n);
//  }

  static List<int> encodeVL(int  length) {
    // TODO: bytes
    List<int> lenBytes = new List<int>(4);

    if (length <= 192)
    {
      lenBytes[0] = length;
      return lenBytes.sublist(0,1);
    }
    else if (length <= 12480)
    {
      length -= 193;

      lenBytes[0] = 193 + (length.abs() >> 8);

      lenBytes[1] = length & 0xff;
      return lenBytes.sublist(0,2);
    }
    else if (length <= 918744) {
      length -= 12481;
      lenBytes[0] = 241 + (length.abs() >> 16);
      lenBytes[1] = (length >> 8) & 0xff;
      lenBytes[2] = length & 0xff;
      return lenBytes.sublist(0,3);
    } else {
      throw new Exception("Overflow error");
    }
  }

  void addList(BytesList bl) {
    for (List<int> bytes in bl.rawList()) {
      sink.addBytes(bytes);
    }
  }

  int addFieldHeader(Field f) {
    if (!f.isSerialized()) {
      throw new Exception("Field %s is a discardable field" + f.toString());
    }
    List<int> n = f.getBytes();
    addBytes(n);
    return n.length;
  }

  void addByte(int type) {
    sink.addByte(type);
  }

  void addLengthEncoded2(BytesList bytes) {
    addBytes(encodeVL(bytes.bytesLength()));
    addList(bytes);
  }

  void add(Field field, SerializedType value) {
    addFieldHeader(field);
    if (field.isVLEncoded()) {
      addLengthEncoded(value);
    } else {
      value.toBytesSink(sink);
      if (field.getType() == Type.STObject) {
        addFieldHeader(Field.ObjectEndMarker);
      } else if (field.getType() == Type.STArray) {
        addFieldHeader(Field.ArrayEndMarker);
      }
    }
  }

  void addLengthEncoded(SerializedType value) {
    BytesList bytes = new BytesList();
    value.toBytesSink(bytes);
    addLengthEncoded2(bytes);
  }
}

==> chainwallet-1.0.4.tar.gz: lib/src/core/serialized/BinarySerializer.dart <==
import 'dart:typed_data';

import "./BytesSink.dart";
import "./ByteList.dart";
import "./SerializedType.dart";
import "../fields/Field.dart";
import "../fields/Type.dart";

class BinarySerializer {
  BytesSink sink;

  BinarySerializer(BytesSink sink) {
    this.sink = sink;
  }

  void addBytes(List<int> n) {
    Uint8List bytes = Uint8List.fromList(n);
    sink.addBytes(bytes);
  }

//  void addLengthEncoded(byte[] n) {
//    add(encodeVL(n.length));
//    add(n);
//  }

  static List<int> encodeVL(int length) {
    // TODO: bytes
    List<int> lenBytes = new List<int>(4);

    if (length <= 192) {
      lenBytes[0] = length;
      return lenBytes.sublist(0, 1);
    } else if (length <= 12480) {
      length -= 193;

      lenBytes[0] = 193 + (length.abs() >> 8);

      lenBytes[1] = length & 0xff;
      return lenBytes.sublist(0, 2);
    } else if (length <= 918744) {
      length -= 12481;
      lenBytes[0] = 241 + (length.abs() >> 16);
      lenBytes[1] = (length >> 8) & 0xff;
      lenBytes[2] = length & 0xff;
      return lenBytes.sublist(0, 3);
    } else {
      throw new Exception("Overflow error");
    }
  }

  void addList(BytesList bl) {
    for (List<int> bytes in bl.rawList()) {
      sink.addBytes(bytes);
    }
  }

  int addFieldHeader(Field f) {
    if (!f.isSerialized()) {
      throw new Exception("Field %s is a discardable field" + f.toString());
    }
    List<int> n = f.getBytes();
    addBytes(n);
    return n.length;
  }

  void addByte(int type) {
    sink.addByte(type);
  }

  void addLengthEncoded2(BytesList bytes) {
    addBytes(encodeVL(bytes.bytesLength()));
    addList(bytes);
  }

  void add(Field field, SerializedType value) {
    addFieldHeader(field);
    if (field.isVLEncoded()) {
      addLengthEncoded(value);
    } else {
      value.toBytesSink(sink);
      if (field.getType() == Type.STObject) {
        addFieldHeader(Field.ObjectEndMarker);
      } else if (field.getType() == Type.STArray) {
        addFieldHeader(Field.ArrayEndMarker);
      }
    }
  }

  void addLengthEncoded(SerializedType value) {
    BytesList bytes = new BytesList();
    value.toBytesSink(bytes);
    addLengthEncoded2(bytes);
  }
}
